#
# spec file for package ispell
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif
%if ! %{defined make_build}
  %define make_build make
%endif
%if ! %{defined make_install}
  %define make_install make
%endif

Name:           ispell
BuildRequires:  bison
BuildRequires:  ncurses-devel
BuildRequires:  words
URL:            https://www.cs.hmc.edu/~geoff/ispell.html
BuildRequires:  fdupes
Requires(post): %fillup_prereq
Provides:       spell
Requires:       ispell_dictionary
Requires:       ispell_english_dictionary
Requires:       words
Version:        3.4.06
Release:        2.4
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        A Spell Checker
License:        BSD-3-Clause
Group:          Productivity/Text/Spell
Source:         https://www.cs.hmc.edu/~geoff/tars/ispell-%{version}.tar.gz
Source1:        SuSEconfig.ispell
Source2:        sysconfig.ispell
Source3:        ispell-rpmlintrc
Patch0:         ispell-3.3.02.dif
Patch1:         ispell-3.3.02-config.patch
Patch2:         ispell-3.2.06-suse.patch
Patch3:         ispell-3.3.02-languages.patch
Patch4:         ispell-3.3.02-types.patch
Patch5:         ispell-3.3.02-terminal.patch
Patch6:         ispell-3.3.02-sq.patch
Patch7:         ispell-3.3.02-brkgcc.patch
Patch8:         ispell-3.3.02-mkdir.patch
Patch9:         ispell-3.3.02-strip.patch
# PATCH-FIX-OPENSUSE correct typo (boo#966124)
Patch10:        boo966124.dif

%description
Ispell is a fast, screen-oriented spell checker that shows you your
errors in the context of the original file and suggests possible
corrections when it can figure them out.  Compared to UNIX spell, it is
faster and much easier to use.	Ispell can also handle languages other
than English.  Ispell has a long history and many people have
contributed to the current version--some of the major contributors
include R. E. Gorin, Pace Willisson, Walt Buehring, and Geoff Kuenning.

You can find a short description in the directory
/usr/share/doc/packages/ispell/.



Authors:
--------
    R. E. Gorin
    Pace Willisson <pace@ai.mit.edu>
    Walt Buehring
    Goeff Kuenning <geoff@ITcorp.com>

%package     -n ispell-american
Summary:        American ispell dictionary
Group:          Productivity/Text/Spell
Provides:       iamerica
Provides:       ispell_dictionary
Provides:       ispell_english_dictionary
Provides:       locale(ispell:en)
Requires(post): bash
Requires(post): ispell
Requires(post): fileutils
Requires(postun):bash
Requires(postun):ispell
Requires(postun):fileutils

%description -n ispell-american
This package includes a ready American dictionary for ispell. If you
install ispell-british too, check /etc/sysconfig/ispell to see which
one the default English dictionary will be. A short usage description
is given in /usr/share/doc/packages/ispell/README. The sources for this
dictionary are included in the source package of ispell.

%package     -n ispell-british
Summary:        British ispell dictionary
Group:          Productivity/Text/Spell
Provides:       ibritish
Provides:       ispell_dictionary
Provides:       ispell_english_dictionary
Provides:       locale(ispell:en_GB)
Requires(post): bash
Requires(post): ispell
Requires(post): fileutils
Requires(postun):bash
Requires(postun):ispell
Requires(postun):fileutils

%description -n ispell-british
This packages includes a ready British dictionary for ispell. If you
install ispell-american too, check /etc/sysconfig/ispell to see which
one will be the default English dictionary. A short usage description
is given in /usr/share/doc/packages/ispell/README. The sources for this
dictionary are included in the source package of ispell.

%package     -n ispell-sq
Summary:        Squeeze or unsqueeze a sorted word list
Group:          Productivity/Text/Spell
Requires:       ispell
Provides:       ispell:%{_bindir}/sq

%description -n ispell-sq
This packages includes the tools sq and unsq which can be used to
squeeze or unsqueeze a sorted word list for better compression.

%prep
%setup
%patch -P0  -p 0 -b .dif
%patch -P1  -p 0 -b .config
%patch -P2  -p 0 -b .suse
%patch -P3  -p 0 -b .languages
%patch -P4  -p 0 -b .types
%patch -P5  -p 0 -b .terminal
%patch -P6  -p 0 -b .sq
%patch -P7  -p 0 -b .brkgcc
%patch -P8  -p 0 -b .mkdir
%patch -P9  -p 0 -b .strip
%patch -P10 -p 0 -b .typo

%build
  PATH=$PATH:$PWD
  export PATH
  make local.h
  make config.sh
  %make_build -j1 all

%install
  DESTDIR=%{buildroot}
  export DESTDIR
  mkdir -p %{buildroot}/usr/doc/packages/ispell
  mkdir -p %{buildroot}%{_prefix}/lib/ispell/emacs
  mkdir -p %{buildroot}%{_fillupdir}
  mkdir -p %{buildroot}/var/lib/dict
  %make_install -j1 DESTDIR=%{buildroot}
  rm -f %{buildroot}/usr/share/emacs/site-lisp/ispell.el*
  install -m 0444 suse/ispell-emacs-menu.el 	%{buildroot}%{_prefix}/lib/ispell/
  install -m 0444 suse/emacs/american.el	%{buildroot}%{_prefix}/lib/ispell/emacs/
  install -m 0444 suse/emacs/british.el		%{buildroot}%{_prefix}/lib/ispell/emacs/
  install -m 0444 suse/emacs/english.el		%{buildroot}%{_prefix}/lib/ispell/emacs/
  rm -f %{buildroot}%{_prefix}/lib/ispell/british.hash
  rm -f %{buildroot}%{_prefix}/lib/ispell/american.hash
  ln -sf britishxlg.hash  %{buildroot}%{_prefix}/lib/ispell/british.hash
  ln -sf americanxlg.hash %{buildroot}%{_prefix}/lib/ispell/american.hash
  mv %{buildroot}%{_prefix}/lib/ispell/english.aff %{buildroot}%{_prefix}/lib/ispell/american.aff
  cp -a %{buildroot}%{_prefix}/lib/ispell/american.aff %{buildroot}%{_prefix}/lib/ispell/british.aff
  install -m 755 %{S:1} %{buildroot}%{_prefix}/lib/ispell/update
  install -m 644 %{S:2} %{buildroot}%{_fillupdir}/
  mkdir -p %{buildroot}/var/lib/dict
  ln -sf %{_prefix}/lib/ispell/american.hash %{buildroot}/var/lib/dict/english.hash
  ln -sf %{_prefix}/lib/ispell/american.aff  %{buildroot}/var/lib/dict/english.aff
  rm -f  %{buildroot}%{_prefix}/lib/ispell/english.hash
  rm -f  %{buildroot}%{_prefix}/lib/ispell/english.aff
  ln -sf /var/lib/dict/english.hash    %{buildroot}%{_prefix}/lib/ispell/
  ln -sf /var/lib/dict/english.aff     %{buildroot}%{_prefix}/lib/ispell/
  rm -f %{buildroot}%{_bindir}/defmt-*
  for man in icombine ijoin
  do
    echo .so man1/ispell.1 > %{buildroot}%{_mandir}/man1/${man}.1
  done
  %fdupes %{buildroot}%{_mandir}

%post
%{fillup_only}

%post -n ispell-american
if test -z "$YAST_IS_RUNNING" -a -x %{_prefix}/lib/ispell/update ; then
    %{_prefix}/lib/ispell/update
fi

%postun -n ispell-american
if test -z "$YAST_IS_RUNNING" -a -x %{_prefix}/lib/ispell/update ; then
    %{_prefix}/lib/ispell/update
fi

%post -n ispell-british
if test -z "$YAST_IS_RUNNING" -a -x %{_prefix}/lib/ispell/update ; then
    %{_prefix}/lib/ispell/update
fi

%postun -n ispell-british
if test -z "$YAST_IS_RUNNING" -a -x %{_prefix}/lib/ispell/update ; then
    %{_prefix}/lib/ispell/update
fi

%files
%doc suse/LIESMICH suse/README
%dir %{_prefix}/lib/ispell
%{_bindir}/buildhash
%{_bindir}/findaffix
%{_bindir}/icombine
%{_bindir}/ijoin
%{_bindir}/ispell
%{_bindir}/munchlist
%{_bindir}/tryaffix
%{_prefix}/lib/ispell/ispell-emacs-menu.el
%dir %{_prefix}/lib/ispell/emacs
%{_prefix}/lib/ispell/emacs/english.el
%{_prefix}/lib/ispell/english.hash
%{_prefix}/lib/ispell/english.aff
%attr(0755,root,root) %{_prefix}/lib/ispell/update
%{_fillupdir}/sysconfig.ispell
%ghost %verify(not link mtime) /var/lib/dict/english.hash
%ghost %verify(not link mtime) /var/lib/dict/english.aff
%doc %{_mandir}/man1/buildhash.1.gz
%doc %{_mandir}/man1/findaffix.1.gz
%doc %{_mandir}/man1/ispell.1.gz
%doc %{_mandir}/man1/icombine.1.gz
%doc %{_mandir}/man1/ijoin.1.gz
%doc %{_mandir}/man1/munchlist.1.gz
%doc %{_mandir}/man1/tryaffix.1.gz
%doc %{_mandir}/man5/ispell.5.gz

%files -n ispell-american
%{_prefix}/lib/ispell/american.hash
%{_prefix}/lib/ispell/americanmed.hash
%{_prefix}/lib/ispell/americanxlg.hash
%{_prefix}/lib/ispell/emacs/american.el
%{_prefix}/lib/ispell/american.aff

%files -n ispell-british
%{_prefix}/lib/ispell/british.hash
%{_prefix}/lib/ispell/britishmed.hash
%{_prefix}/lib/ispell/britishxlg.hash
%{_prefix}/lib/ispell/emacs/british.el
%{_prefix}/lib/ispell/british.aff

%files -n ispell-sq
%{_bindir}/sq
%{_bindir}/unsq
%doc %{_mandir}/man1/sq.1.gz
%doc %{_mandir}/man1/unsq.1.gz

%changelog
* Tue Feb 20 2024 Dr. Werner Fink <werner@suse.de>
- Split off sq and unsq into an own package to provide namespace
  for sequoia-sq
* Sun Nov 26 2023 Dirk Müller <dmueller@suse.com>
- update to 3.4.06:
  * Fix a place where buildhash could reference beyond the end of
    the hash table, causing a segfault if that happened to cross a
    page boundary.
  * dictionary updates
* Wed Nov 15 2023 Dr. Werner Fink <werner@suse.de>
- The dictionaries require at (un)install the update script of
  ispell (boo#1217133)
* Fri Oct  7 2022 Dr. Werner Fink <werner@suse.de>
- Update to ispell 3.4.05
  * A major bug in 3.4.01 that caused incorrect behavior with many
    languages has been corrected.
  * The default maximum number of stringchars has been doubled.
  * Some spurious compiler warnings have been suppressed.
  * The english.aff file has been revised so that UTF-8 is now the
    default encoding for English dictionaries.
  * Some subtle bugs with the handling of stringchars, which were
    revealed by the changes to english.aff, have been corrected.
  * A new affix command, "options", has been added to allow selection
    of options related to a particular string character type.  There
    are currently two options, raw_display and squeeze_strings.  Both
    should be activated for UTF-8 encodings but few others.  This
    change causes hash files built with earlier ispell versions to be
    incompatible; old hash files will need to be rebuilt.
  * Over 6000 words have been added to the English dictionaries.  Most
    of them are in the english.xlg variant, but some are included in
    smaller dictionaries as well.  The English dictionaries also take
    advantage of the new UTF-8 encoding to support correct spellings of
    words adopted from other languages, such as crêpe.
- Port patches
  * boo966124.dif
  * ispell-3.3.02-brkgcc.patch
  * ispell-3.3.02-config.patch
  * ispell-3.3.02-mkdir.patch
  * ispell-3.3.02-sq.patch
  * ispell-3.3.02-strip.patch
  * ispell-3.3.02-terminal.patch
  * ispell-3.3.02-types.patch
  * ispell-3.3.02.dif
* Mon Aug 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%{_prefix}/lib instead of %%{_libexecdir}: the path is
  hardcoded in quite a few scripts, config files and the
  documentation (boo#1174075).
* Sun Jan 14 2018 werner@suse.de
- Avoid `set -e' in munchlist (boo#1075882)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Feb 28 2017 werner@suse.de
- Use modern regular expressions for character sets in lisp
  declarations for the dictionaries
* Tue Feb 14 2017 werner@suse.de
- Make ispell-dictionary-alist reload caused by menu setup, for this
  use the hook ispell-initialize-spellchecker-hook
* Tue Nov 22 2016 werner@suse.de
- Extend patch boo966124.dif for bug boo#1010330
* Mon May 30 2016 werner@suse.de
- Extend patch boo966124.dif for bug boo#981024
* Fri Feb 12 2016 werner@suse.de
- Update to ispell 3.4.00
  * The english.5 manual page has been dropped
  * Ispell now supports systems (BSD) that foolish discarded backwards
    compatibility and insist on using termios.
  * An error has been corrected in the English affix files that caused
    certain words ending in "th" to be pluralized incorrectly.  The
    dictionaries have been updated to ensure that no incorrect plurals
    have crept in.
  * The personal dictionary is now written in a stable order when there
    are multiple variant capitalizations of a word.
  * A bug in TeX deformatting has been corrected.  Previously, two
    adjacent math-mode environments introduced with dollar signs, such
    as $a=b$$c=d$, would cause ispell to lose track of whether it was
    in math mode.
  * he American and British Makefiles have been simplified to ensure
    that dictionaries are always built with the lastest information.
- Modify patches
  ispell-3.3.02-config.patch
  ispell-3.3.02-languages.patch
  ispell-3.3.02-sq.patch
  ispell-3.3.02-strip.patch
  ispell-3.3.02-terminal.patch
  ispell-3.3.02-types.patch
  ispell-3.3.02.dif
- Remove patch ispell-3.3.02-getline.patch now upstream
- Add patch boo966124.dif that is correct typo in english.3 word
  list (boo#966124)
* Tue Feb 10 2015 werner@suse.de
- Xemacs knows about define-coding-system-alia therefore use it (boo#896947)
* Wed Feb  4 2015 werner@suse.de
- Use real POSIX shell syntax
- Fix ispell update script thas is do not try to source old SUSE
  config files (boo#916001)
* Sat Dec 13 2014 Led <ledest@gmail.com>
- fix bashism in SuSEconfig.ispell (update) script
* Mon Dec  9 2013 werner@suse.de
- Remove mixed patch leftover
* Fri Dec  6 2013 werner@suse.de
- Hint from Björn Jacke that old style sort is broken, therefore
  enforce usage of modern sort options
* Mon Jun 18 2012 werner@suse.de
- Rename and relocate SuSEconfig.ispell
* Wed Feb  1 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Fri Aug 20 2010 werner@suse.de
- Run SuSEconfig.ispell if YaST is not used to make sure that we
  have an english dictionary
* Sun Aug 30 2009 coolo@novell.com
- provide Patch0
* Sun Jun  7 2009 ro@suse.de
- rename getline to my_getline to avoid conflict with function
  from glibc
* Thu May 31 2007 werner@suse.de
- Update ispell to version 3.3.02 including various bug fixes
  and add new old html parser and support for UTF-8.
* Thu May 31 2007 werner@suse.de
- Fix sq/unsq, hint from Thomas Rachel
* Thu Mar 29 2007 rguenther@suse.de
- Add bison and ncurses-devel BuildRequires.
* Mon May 22 2006 schwab@suse.de
- Don't strip binaries.
* Wed Mar 29 2006 werner@suse.de
- Add locale provides (bug #161478)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 werner@suse.de
- Fix dangling symlink (bug #142828)
* Fri Jul  1 2005 werner@suse.de
- Make it build-root and no norootforbuild
* Thu Jun  2 2005 mfabian@suse.de
- fix ispell-emacs-menu.el for XEmacs 21.5.20 and
  xemacs-packages-20050505 (coding system iso-8859-14 may not
  exist without requiring 'latin-euro-latin8).
* Thu Mar 10 2005 werner@suse.de
- Use /var/lib/dict/ to handle ro /usr/share/dict/ and the symbolic
  link `english.hash/aff' to the choosen dictionary (bug #67048)
* Tue Dec 21 2004 werner@suse.de
- Be sure that the string utils uses the POSIX locale
* Mon May  3 2004 werner@suse.de
- Add break condition for checking HUGE lines to avoid side effect
  of the new ``compensate for short copy strategy'' (bug #39745)
* Thu Jan  8 2004 ro@suse.de
- fix build with current bison
* Fri Aug 29 2003 werner@suse.de
- More about new POSIX sort behaviour: one fix in munchlist
  and four fixes in findaffix (bug #29627).
* Thu Aug 28 2003 mmj@suse.de
- Add sysconfig metadata [#28885]
* Thu Jul 24 2003 werner@suse.de
- Fix encode mappings for Xemacs
* Tue Apr  8 2003 werner@suse.de
- Fix munchlist sort using
- Fix Makefile's sort using
- Use secure tmp directory for munchlist
* Tue Apr  8 2003 werner@suse.de
- Use -n option for tail
- Use iso-latin-1 even for english dictionaries to avoid splits
- Add some more comments about new german and the DICTIONARY var
* Thu Feb 20 2003 mmj@suse.de
- Add sysconfig metadata [#22650]
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Aug 15 2002 ro@suse.de
- fixed typo in specfile
* Thu Aug 15 2002 werner@suse.de
- Add pre-requires (bug #17885)
* Mon May 13 2002 egmont@suselinux.hu
- use RC_LANG instead of obsolete DEFAULT_LANGUAGE
* Tue Apr 16 2002 adrian@suse.de
- add Provides spell (kdelibs3 needs either ispell or aspell now)
* Thu Mar  7 2002 egmont@suselinux.hu
- Fixed template comment
* Wed Feb 20 2002 werner@suse.de
- Avoid circular depndencies (bug #13609)
* Mon Feb  4 2002 egmont@suselinux.hu
- SuSE GmbH -> SuSE Linux AG
* Thu Jan 24 2002 werner@suse.de
- Make MASKTYPE to a string (thanks to Jan Cihlar)
* Wed Jan 16 2002 egmont@suselinux.hu
- Rename packages to ispell-american and ispell-british
- They no longer have common files, no longer exclude each other
- New SuSEconfig module to generate the "english" symlinks
* Thu Dec 13 2001 werner@suse.de
- Fix the sq patch gets versus fgets, the newline problem (#12461)
- No backslashspace patch anymore required
* Thu Sep 27 2001 werner@suse.de
- Update to ispell 3.2.06
  * port missed patches to 3.2.06
  * curent missing patches are
    ISO part of html mode and maybe backslashspace workaround
* Thu May 17 2001 werner@suse.de
- Mask all exit status with true on unlinking english.hash
* Mon May 14 2001 werner@suse.de
- Be sure that exit status is true in preun scripts
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Wed Feb  7 2001 werner@suse.de
- Workaround for broken gcc on IA64
- Split main dif into several patches
- Add backslash space patch for TeX text
- Add iso-more-html patch for HTML text
* Wed Jan 10 2001 werner@suse.de
- Make temporary files more secure
* Sat Oct 14 2000 schwab@suse.de
- Do not define bcopy and bzero on Linux.
* Mon Sep 18 2000 werner@suse.de
- Change ispell-emacs-menu.el to fit filter feature
  in ispell-menu-xemacs of newer ispell.el of XEmacs
  - Change ispell-emacs-menu.el to add local used
  dictionary list.
* Sat May 27 2000 kukuk@suse.de
- Use doc macro
* Mon Mar 13 2000 werner@suse.de
- Use tc[sg]etattr if possible
  - Use correct pointer size depending on __WORDSIZE
  - Fix common names with ncurses
  - Use $RPM_OPT_FLAGS
  - Use correct type for {m,re}alloc
  - Don't require ispell for ibritish and iamerica because
  ispell requires one of those packages (bootstrapping)
* Fri Feb 25 2000 kukuk@suse.de
- Move /usr/{info,man} -> /usr/share/{info,man}
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Mon Sep 20 1999 ro@suse.de
- added Requires ispell_dictionary for ispell
- added Provides ispell_dictionary for ibritish, iamerica
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jul 14 1999 werner@suse.de
- Avoid load messages during rebuild of emacs spell menue
* Thu Mar  4 1999 werner@suse.de
- Preparing for a better (x)emacs interface: Implement a
  emacs lisp file to create the spell menus modular on the
  fly in both emacs and xemacs Edit pulldown.
* Fri Nov 13 1998 bs@suse.de
- fixed spec file (double entry Summary)
* Thu Nov 12 1998 bs@suse.de
- fixed spec file for new rpm.
* Thu Sep 10 1998 ro@suse.de
- catch redefinition of strcmp in ijoin.c
* Thu Jul  9 1998 werner@suse.de
- Some preun scripts for ibritish and iamerica
* Wed Jul  8 1998 werner@suse.de
- Split ispell into ispell for binaries and two
  packages ibritish and iamerica (excluding each other)
* Fri Feb  6 1998 werner@suse.de
- Move hk2-deutsch to igerman and dicts package
  - Fix flag handling (flags [\]^_` are not reconginzed by isalpha)
  - Fix bug in fix8bit (wrong handling of second figure of a hex number)
* Fri Oct 17 1997 werner@suse.de
- Move description from pac to /usr/doc/packages/ispell
  - Fix ispell.texinfo
* Thu Feb  6 1997 werner@suse.de
- Repacked
  - A small modification: Now there is an environment variable
  CHARSET which will be used if and only if the environment variable
  DICTIONARY is set. E.g. DICTIONARY=deutsch and CHARSET=latin1
  Therefore `-T' is not needed ... `-n', `-t' and `-T'
    overwrites CHARSET.
